@@ -6,15 +6,11 @@ pyrolite includes a limited mineral database which is useful for looking up endm
 compositions.
 """
 import pandas as pd
-from pyrolite.mineral.mindb import (
-    list_groups,
-    list_minerals,
-    list_formulae,
-    get_mineral,
-    get_mineral_group,
-)
 
-pd.set_option("precision", 3)  # smaller outputs
+from pyrolite.mineral.mindb import (get_mineral, get_mineral_group,
+                                    list_formulae, list_groups, list_minerals)
+
+pd.set_option("display.precision", 3)  # smaller outputs
 ########################################################################################
 # From the database, you can get the list of its contents using a few utility
 # functions:
