@@ -15,23 +15,23 @@ from .mindb import get_mineral_group, list_minerals, parse_composition
 logger = Handle(__name__)
 
 # minerals for the CIPW Norm
-NORM_MINERALS = minerals = {
+NORM_MINERALS = {
     "Q": {"name": "quartz", "formulae": "SiO2"},
     "Z": {"name": "zircon", "formulae": "ZrO2 SiO2", "SINCLAS_abbrv": "ZIR"},
     "Ks": {"name": "potassium metasilicate", "formulae": "K2O SiO2"},
-    "An": {"name": "anorthite", "formulae": "CaO Al2O3 2SiO2"},
+    "An": {"name": "anorthite", "formulae": "CaO Al2O3 (SiO2)2"},
     "Ns": {"name": "sodium metasilicate", "formulae": "Na2O SiO2"},
-    "Ac": {"name": "acmite", "formulae": "Na2O Fe2O3 4SiO2"},
+    "Ac": {"name": "acmite", "formulae": "Na2O Fe2O3 (SiO2)4"},
     "Th": {"name": "thenardite", "formulae": "Na2O SO3"},
-    "Ab": {"name": "albite", "formulae": "Na2O Al2O3 6SiO2"},
-    "Or": {"name": "orthoclase", "formulae": "K2O Al2O3 6SiO2"},
+    "Ab": {"name": "albite", "formulae": "Na2O Al2O3 (SiO2)6"},
+    "Or": {"name": "orthoclase", "formulae": "K2O Al2O3 (SiO2)6"},
     "Pf": {"name": "perovskite", "formulae": "CaO TiO2", "SINCLAS_abbrv": "PER"},
-    "Ne": {"name": "nepheline", "formulae": "Na2O Al2O3 2SiO2"},
-    "Lc": {"name": "leucite", "formulae": "K2O Al2O3 4SiO2"},
-    "Cs": {"name": "dicalcium silicate", "formulae": "2CaO SiO2"},
-    "Kp": {"name": "kaliophilite", "formulae": "K2O Al2O3 2SiO2"},
-    "Ap": {"name": "apatite", "formulae": "(3CaO) P2O5 (0.33333CaO)"},
-    "CaF2-Ap": {"name": "fluroapatite", "formulae": "(3CaO) P2O5 (0.33333CaO)"},
+    "Ne": {"name": "nepheline", "formulae": "Na2O Al2O3 (SiO2)2"},
+    "Lc": {"name": "leucite", "formulae": "K2O Al2O3 (SiO2)4"},
+    "Cs": {"name": "dicalcium silicate", "formulae": "(CaO)2 SiO2"},
+    "Kp": {"name": "kaliophilite", "formulae": "K2O Al2O3 (SiO2)2"},
+    "Ap": {"name": "apatite", "formulae": "(CaO)3 P2O5 (CaO)0.33333"},
+    "CaF2-Ap": {"name": "fluroapatite", "formulae": "(CaO)3 P2O5 (CaO)0.33333"},
     "Fr": {"name": "fluorite", "formulae": "CaF2"},
     "Pr": {"name": "pyrite", "formulae": "FeS2", "SINCLAS_abbrv": "PYR"},
     "Cm": {"name": "chromite", "formulae": "FeO Cr2O3", "SINCLAS_abbrv": "CHR"},
@@ -41,33 +41,32 @@ NORM_MINERALS = minerals = {
     "Ru": {"name": "rutile", "formulae": "TiO2"},
     "Mt": {"name": "magnetite", "formulae": "FeO Fe2O3"},
     "Hm": {"name": "hematite", "formulae": "Fe2O3", "SINCLAsS_abbrv": "HE"},
-    "Mg-Ol": {"name": "forsterite", "formulae": "2MgO SiO2", "SINCLAS_abbrv": "FO"},
-    "Fe-Ol": {"name": "fayalite", "formulae": "2FeO SiO2", "SINCLAS_abbrv": "FA"},
+    "Mg-Ol": {"name": "forsterite", "formulae": "(MgO)2 SiO2", "SINCLAS_abbrv": "FO"},
+    "Fe-Ol": {"name": "fayalite", "formulae": "(FeO)2 SiO2", "SINCLAS_abbrv": "FA"},
     "Fe-Di": {
         "name": "clinoferrosilite",
-        "formulae": "CaO FeO 2SiO2",
+        "formulae": "CaO FeO (SiO2)2",
         "SINCLAS_abbrv": "DIF",
     },
     "Mg-Di": {
         "name": "clinoenstatite",
-        "formulae": "CaO MgO 2SiO2",
+        "formulae": "CaO MgO (SiO2)2",
         "SINCLAS_abbrv": "DIM",
     },
     "Fe-Hy": {"name": "ferrosilite", "formulae": "FeO SiO2", "SINCLAS_abbrv": "HYF"},
     "Mg-Hy": {"name": "enstatite", "formulae": "MgO SiO2", "SINCLAS_abbrv": "HYM"},
-    # additions
-    "Tn": {"name": "titanite", "formulae": "CaO TiO2 SiO2", "SINCLAS_abbrv": "SPH"},
     "Wo": {"name": "wollastonite", "formulae": "CaO SiO2"},
-    "Di": {"name": "diopside", "formulae": "CaO MgO 2SiO2"},
-    "Hy": {"name": "hypersthene", "formulae": "MgO SiO2"},
-    "Ol": {"name": "olivine", "formulae": "2MgO SiO2"},
-    "Hl": {"name": "halite", "formulae": "NaCl", "SINCLAS_abbrv": "HL"},
     "Nc": {"name": "cancrinite", "formulae": "Na2O CO2", "SINCLAS_abbrv": "CAN"},
+    "Hl": {"name": "halite", "formulae": "NaCl", "SINCLAS_abbrv": "HL"},
+    "Tn": {"name": "titanite", "formulae": "CaO TiO2 SiO2", "SINCLAS_abbrv": "SPH"},
+    "Di": {"name": "diopside", "formulae": "CaO MgO (SiO2)2"},
+    "Hy": {"name": "hypersthene", "formulae": "MgO SiO2"},
+    "Ol": {"name": "olivine", "formulae": "(MgO)2 SiO2"},
 }
 
 # Add standard masses to minerals
 for mineral in NORM_MINERALS.keys():
-    NORM_MINERALS[mineral]["mass"] = pt.formula(NORM_MINERALS[mineral]["formulae"])
+    NORM_MINERALS[mineral]["mass"] = pt.formula(NORM_MINERALS[mineral]["formulae"]).mass
 
 
 def unmix(comp, parts, ord=1, det_lim=0.0001):
@@ -202,6 +201,69 @@ def endmember_decompose(
 # CIPW Norm and Related functions
 ################################################################################
 
+from ..util.classification import TAS
+
+# fuctions which map <TAS field, [SiO2, Na2O + K2O]> to Fe2O3/FeO ratios.
+_MiddlemostTASRatios = dict(
+    F=lambda t, x: 0.4 if x[1] > 10 else 0.3,
+    Ph=lambda t, x: 0.5,
+    T1=lambda t, x: 0.5,
+    T2=lambda t, x: 0.5,
+    R=lambda t, x: 0.5,
+    O3=lambda t, x: 0.4,
+    S3=lambda t, x: 0.4,
+    U3=lambda t, x: 0.4,
+    O2=lambda t, x: 0.35,
+    S2=lambda t, x: 0.35,
+    U2=lambda t, x: 0.35,
+    O1=lambda t, x: 0.3,
+    S1=lambda t, x: 0.3,
+    U1=lambda t, x: 0.3 if x[1] > 6 else 0.2,
+    Ba=lambda t, x: 0.2,
+    Bs=lambda t, x: 0.2,
+    Pc=lambda t, x: 0.15,
+)
+
+
+def MiddlemostOxRatio(df):
+    """
+    Apply a TAS classification to a dataframe, and get estimated Fe2O3/FeO ratios
+    from Middlemost (1989).
+
+    Parameters
+    ----------
+    df : :class:`pandas.DataFrame`
+        Dataframe to get Fe2O3/FeO ratios for, containing the required oxides
+        to calculate TAS diagrams from (i.e. SiO2, Na2O, K2O).
+
+    Returns
+    -------
+    ratios : :class:`pandas.Series`
+        Series of estimated Fe2O3/FeO ratios, based on TAS classification.
+
+    References
+    ----------
+    Middlemost, Eric A. K. (1989). Iron Oxidation Ratios, Norms and the
+    Classification of Volcanic Rocks. Chemical Geology 77, 1: 19–26.
+    https://doi.org/10.1016/0009-2541(89)90011-9.
+    """
+    TAS_input = df.apply(
+        lambda x: pd.Series(
+            {"SiO2": x.SiO2, "Na2O + K2O": x.reindex(index=["Na2O", "K2O"]).sum()}
+        ),
+        axis=1,
+    )
+    TAS_fields = TAS().predict(TAS_input)
+    TAS_fields.name = "TAS"
+    ratios = pd.concat([TAS_input, TAS_fields], axis=1).apply(
+        lambda x: _MiddlemostTASRatios.get(x.TAS, lambda t, x: np.nan)(
+            x.TAS, x.values[:2]
+        ),
+        axis=1,
+    )
+    ratios.name = "Fe2O3/FeO"
+    return ratios
+
 
 def LeMaitreOxRatio(df, mode=None):
     r"""
@@ -219,7 +281,7 @@ def LeMaitreOxRatio(df, mode=None):
 
     Notes
     ------
-    This is a :math:`\mathrm{FeO / (FeO + Fe_2O_3)}` mass ratio, not a standar
+    This is a :math:`\mathrm{FeO / (FeO + Fe_2O_3)}` mass ratio, not a standard
     molar ratio :math:`\mathrm{Fe^{2+}/(Fe^{2+} + Fe^{3+})}` which is more
     straightfowardly used; data presented should be in mass units. For the
     calculation, SiO2, Na2O and K2O are expected to be present.
@@ -246,20 +308,51 @@ def LeMaitreOxRatio(df, mode=None):
         ratio = (
             0.93
             - 0.0042 * df["SiO2"].fillna(0)
-            - 0.022 * df.reindex(columns=["Na2O", "K2O"]).sum(axis=1).fillna(0)
+            - 0.022 * df.reindex(columns=["Na2O", "K2O"]).sum(axis=1)
         )
     else:
         logger.debug("Using LeMaitre Plutonic Fe Correction.")
         ratio = (
             0.88
             - 0.0016 * df["SiO2"].fillna(0)
-            - 0.027 * df.reindex(columns=["Na2O", "K2O"]).sum(axis=1).fillna(0)
+            - 0.027 * df.reindex(columns=["Na2O", "K2O"]).sum(axis=1)
         )
     ratio.loc[ratio.values < 0] = 0.0
     ratio.name = "FeO/(FeO+Fe2O3)"
     return ratio
 
 
+def Middlemost_Fe_correction(df):
+    r"""
+    Parameters
+    -----------
+    df : :class:`pandas.DataFrame`
+        Dataframe containing compositions to calibrate against.
+
+    Returns
+    -------
+    :class:`pandas.DataFrame`
+        Series with two corrected iron components
+        (:math:`\mathrm{FeO, Fe_2O_3}`).
+
+    References
+    ----------
+    Middlemost, Eric A. K. (1989). Iron Oxidation Ratios, Norms and the
+    Classification of Volcanic Rocks. Chemical Geology 77, 1: 19–26.
+    https://doi.org/10.1016/0009-2541(89)90011-9.
+    """
+    mass_ratios = MiddlemostOxRatio(df)  # mass ratios
+    # note, the Fe2O3/FeO ratio instead of e.g. Fe2O3/(FeO + Fe2O3)
+    mole_ratios = mass_ratios / (pt.formula("Fe2O3").mass / pt.formula("FeO").mass)
+    mole_ratios = mole_ratios * 2  # pyrolite's to_molecular uses moles Fe, not Fe2O3
+    Fe2O3_mole_fraction = mole_ratios / (mole_ratios + 1)
+    FeO_mole_fraction = 1 - Fe2O3_mole_fraction
+    to = {"FeO": FeO_mole_fraction, "Fe2O3": Fe2O3_mole_fraction}
+    return df.reindex(
+        columns=["FeO", "Fe2O3", "FeOT", "Fe2O3T"]
+    ).pyrochem.convert_chemistry(to=[to])
+
+
 def LeMaitre_Fe_correction(df, mode="volcanic"):
     r"""
     Parameters
@@ -277,7 +370,6 @@ def LeMaitre_Fe_correction(df, mode="volcanic"):
 
     References
     ----------
-
     Le Maitre, R. W (1976). Some Problems of the Projection of Chemical Data
     into Mineralogical Classifications.
     Contributions to Mineralogy and Petrology 56, no. 2 (1 January 1976): 181–89.
@@ -287,18 +379,17 @@ def LeMaitre_Fe_correction(df, mode="volcanic"):
     Classification of Volcanic Rocks. Chemical Geology 77, 1: 19–26.
     https://doi.org/10.1016/0009-2541(89)90011-9.
     """
-    mass_ratios = LeMaitreOxRatio(df, mode=mode).values  # mass ratios
-    # get the FeO + Fe2O3 mass sum, which we can multiply by the oxidation
-    # ratio to get FeO, Fe2O3
-    sumFeOxides = (
-        df.reindex(columns=["FeO", "FeOT", "Fe2O3", "Fe2O3T"]).sum(axis=1).values
-    )
-    converted = pd.DataFrame(
-        sumFeOxides[:, None] * np.vstack([mass_ratios, 1.0 - mass_ratios]).T,
-        columns=["FeO", "Fe2O3"],
-        index=df.index,
-    )
-    return converted
+    mass_ratios = LeMaitreOxRatio(df, mode=mode)  # mass ratios
+    # convert mass ratios to mole (Fe) ratios - moles per unit mass for each
+    feo_moles = mass_ratios / pt.formula("FeO").mass
+    fe2O3_moles = (1 - mass_ratios) / pt.formula("Fe2O3").mass * 2
+    Fe_mole_ratios = feo_moles / (feo_moles + fe2O3_moles)
+
+    to = {"FeO": Fe_mole_ratios, "Fe2O3": 1 - Fe_mole_ratios}
+
+    return df.reindex(
+        columns=["FeO", "Fe2O3", "FeOT", "Fe2O3T"]
+    ).pyrochem.convert_chemistry(to=[to])
 
 
 def _update_molecular_masses(mineral_dict, corrected_mass_df):
@@ -319,17 +410,18 @@ def _update_molecular_masses(mineral_dict, corrected_mass_df):
         masses = 0.0
         for oxide in composition.split():
             count = re.findall(r"(?<![a-zA-Z:])[-+]?\d*\.?\d+", oxide)
+            normalised_oxide_name = re.findall(r"[a-zA-Z\d]+", oxide)[0]
 
             if len(count) > 0:
                 count = float(count[0])
             else:
                 count = 1
 
-            if oxide in corrected_mass_df:
-                mass = count * corrected_mass_df[oxide]
+            if normalised_oxide_name in corrected_mass_df:
+                mass = count * corrected_mass_df[normalised_oxide_name]
             else:
                 # get the components which don't have adjusted molecular weights
-                mass = pt.formula(oxide).mass
+                mass = pt.formula(normalised_oxide_name).mass * count
             masses += mass
         data["mass"] = masses
 
@@ -350,7 +442,6 @@ def _aggregate_components(df, to_component, from_components, corrected_mass):
         Minor oxide components to aggregate from.
     corrected_mass : :class:`pandas.DataFrame`
         Dataframe to put corrected masses.
-
     """
     target = "n_{}_corr".format(to_component)
     # ensure the main component is included..
@@ -369,7 +460,6 @@ def CIPW_norm(df, Fe_correction=None, Fe_correction_mode=None, adjust_all_Fe=Fal
     """
     Standardised calcuation of estimated mineralogy from bulk rock chemistry.
     Takes a dataframe of chemistry & creates a dataframe of estimated mineralogy.
-
     This is the CIPW norm of Verma et al. (2003).  This version only uses major
     elements.
 
@@ -391,10 +481,8 @@ def CIPW_norm(df, Fe_correction=None, Fe_correction_mode=None, adjust_all_Fe=Fal
 
     References
     ----------
-
     Verma, Surendra P., Ignacio S. Torres-Alvarado, and Fernando Velasco-Tapia (2003).
     A Revised CIPW Norm. Swiss Bulletin of Mineralogy and Petrology 83, 2: 197–216.
-
     Verma, S. P., & Rivera-Gomez, M. A. (2013). Computer Programs for the
     Classification and Nomenclature of Igneous Rocks. Episodes, 36(2), 115–124.
 
@@ -411,7 +499,7 @@ def CIPW_norm(df, Fe_correction=None, Fe_correction_mode=None, adjust_all_Fe=Fal
         "The current CIPW Norm implmentation is under continuting development, "
         "and does not yet return expected results."
     )
-
+    minerals = {**NORM_MINERALS}  # copy of NORM_MINERALS
     noncrit = [
         "CO2",
         "SO3",
@@ -435,6 +523,22 @@ def CIPW_norm(df, Fe_correction=None, Fe_correction_mode=None, adjust_all_Fe=Fal
         + noncrit
     )
 
+    majors = [
+        "SiO2",
+        "TiO2",
+        "Al2O3",
+        "Fe2O3",
+        "FeO",
+        "MnO",
+        "MgO",
+        "CaO",
+        "Na2O",
+        "K2O",
+        "P2O5",
+    ]
+
+    trace = ["F", "Cl", "S", "Ni", "Co", "Sr", "Ba", "Rb", "Cs", "Li", "Zr", "Cr", "V"]
+
     # Check that all of the columns we'd like are present
     to_impute = []
     if not set(columns).issubset(set(df.columns.values)):
@@ -471,6 +575,8 @@ def CIPW_norm(df, Fe_correction=None, Fe_correction_mode=None, adjust_all_Fe=Fal
         df.loc[fltr, ["FeO", "Fe2O3"]] = LeMaitre_Fe_correction(
             df.loc[fltr, :], mode=Fe_correction_mode
         )
+    elif Fe_correction.lower().startswith("middle"):
+        df.loc[fltr, ["FeO", "Fe2O3"]] = Middlemost_Fe_correction(df.loc[fltr, :])
     else:
         raise NotImplementedError(
             "Iron correction {} not recognised.".format(Fe_correction)
@@ -479,22 +585,6 @@ def CIPW_norm(df, Fe_correction=None, Fe_correction_mode=None, adjust_all_Fe=Fal
     # select just the columns we'll use; remove e.g. FeOT, Fe2O3T which have been recalcuated
     df = df.reindex(columns=columns).fillna(0)
 
-    majors = [
-        "SiO2",
-        "TiO2",
-        "Al2O3",
-        "Fe2O3",
-        "FeO",
-        "MnO",
-        "MgO",
-        "CaO",
-        "Na2O",
-        "K2O",
-        "P2O5",
-    ]
-
-    trace = ["F", "Cl", "S", "Ni", "Co", "Sr", "Ba", "Rb", "Cs", "Li", "Zr", "Cr", "V"]
-
     # convert ppm traces to wt%
     df.loc[:, trace] *= scale("ppm", "wt%")
 
@@ -528,56 +618,140 @@ def CIPW_norm(df, Fe_correction=None, Fe_correction_mode=None, adjust_all_Fe=Fal
     # Adjust majors wt% to 100% then adjust again to account for trace components
     ############################################################################
     # Rounding to 3 dp
-    df.loc[:, majors] = df.loc[:, majors].round(3)
+    df[majors] = df[majors].round(3)
 
     # First adjustment
-    df["initial_sum"] = df.loc[:, majors].sum(axis=1)
-    adjustment_factor = 100.0 / df["initial_sum"].values
-    df.loc[:, majors] = df.loc[:, majors].mul(adjustment_factor, axis=0)
+    df["intial_sum"] = df[majors].sum(axis=1)
+    adjustment_factor = 100.0 / df["intial_sum"]
+    df[majors] = df[majors].mul(adjustment_factor, axis=0)
 
     # Second adjustment
-    df["major_minor_sum"] = df.loc[:, majors].sum(axis=1) + df.loc[:, minors_trace].sum(
-        axis=1
-    )
+    df["major_minor_sum"] = df[majors].sum(axis=1) + df[minors_trace].sum(axis=1)
     adjustment_factor = 100.0 / df["major_minor_sum"]
 
-    df.loc[:, majors + minors_trace] = df.loc[:, majors + minors_trace].mul(
-        adjustment_factor, axis=0
-    )
+    df[majors + minors_trace] = df[majors + minors_trace].mul(adjustment_factor, axis=0)
+
+    ox_adjusted = df.copy(deep=True)
 
     ############################################################################
     # Mole Calculations
     # TODO: update to use df.pyrochem.to_molecular()
     ############################################################################
     for component in majors + minors_trace:
-        df.loc[:, component] /= pt.formula(component).mass
+        df[component] = df[component] / pt.formula(component).mass
 
     ############################################################################
     # Combine minor components, compute minor component fractions and correct masses
     ############################################################################
-    corrected_mass = pd.DataFrame()
 
-    for major, minors in [
-        ("FeO", ["MnO", "NiO", "CoO"]),
-        ("CaO", ["SrO", "BaO"]),
-        ("K2O", ["Rb2O", "Cs2O"]),
-        ("Na2O", ["Li2O"]),
-        ("Cr2O3", ["V2O3"]),
-    ]:
-        _aggregate_components(df, major, minors, corrected_mass)
+    ###########################
+    # Code below does not work
+    ###########################
+
+    # corrected_mass = pd.DataFrame()
+
+    # for major, minors in [
+    #     ("FeO", ["MnO", "NiO", "CoO"]),
+    #     ("CaO", ["SrO", "BaO"]),
+    #     ("K2O", ["Rb2O", "Cs2O"]),
+    #     ("Na2O", ["Li2O"]),
+    #     ("Cr2O3", ["V2O3"]),
+    # ]:
+    #     _aggregate_components(df, major, minors, corrected_mass)
+
+    # # Corrected molecular weight of Ca, Na and Fe
+    # corrected_mass["Ca"] = corrected_mass["CaO"] - pt.O.mass
+    # corrected_mass["Na"] = (corrected_mass["Na2O"] - pt.O.mass) / 2
+    # corrected_mass["Fe"] = corrected_mass["FeO"] - pt.O.mass
+
+    # # Get mineral data, update with corrected masses
+
+    # minerals = {
+    #     k: {**v} for k, v in NORM_MINERALS.items()
+    # }  # copy the dictionary rather than edit it
+
+    # _update_molecular_masses(minerals, corrected_mass)
+
+    # Minor oxide combinations
+
+    df["n_FeO_corr"] = df[["FeO", "MnO", "NiO", "CoO"]].sum(axis=1)
+    df["n_CaO_corr"] = df[["CaO", "SrO", "BaO"]].sum(axis=1)
+    df["n_K2O_corr"] = df[["K2O", "Rb2O", "Cs2O"]].sum(axis=1)
+    df["n_Na2O_corr"] = df[["Na2O", "Li2O"]].sum(axis=1)
+    df["n_Cr2O3_corr"] = df[["Cr2O3", "V2O3"]].sum(axis=1)
+
+    # Corrected oxide molecular weight computations
+
+    df[["x_MnO", "x_FeO"]] = df[["MnO", "FeO"]] / df[["n_FeO_corr"]].values
+    df[["x_NiO", "x_CoO"]] = df[["NiO", "CoO"]] / df[["n_FeO_corr"]].values
+    df[["x_SrO", "x_BaO", "x_CaO"]] = (
+        df[["SrO", "BaO", "CaO"]] / df[["n_CaO_corr"]].values
+    )
+    df[["x_Rb2O", "x_Cs2O", "x_K2O"]] = (
+        df[["Rb2O", "Cs2O", "K2O"]] / df[["n_K2O_corr"]].values
+    )
+    df[["x_Li2O", "x_Na2O"]] = df[["Li2O", "Na2O"]] / df[["n_Na2O_corr"]].values
+    df[["x_V2O3", "x_Cr2O3"]] = df[["V2O3", "Cr2O3"]] / df[["n_Cr2O3_corr"]].values
+
+    df[["FeO", "CaO", "K2O", "Na2O", "Cr2O3"]] = df[
+        ["n_FeO_corr", "n_CaO_corr", "n_K2O_corr", "n_Na2O_corr", "n_Cr2O3_corr"]
+    ].values
+
+    # Corrected normative mineral molecular weight computations
+    def corr_m_wt(oxide):
+        return df["x_" + oxide] * pt.formula(oxide).mass
+
+    df["MW_FeO_corr"] = (
+        corr_m_wt("MnO") + corr_m_wt("NiO") + corr_m_wt("CoO") + corr_m_wt("FeO")
+    )
+    df["MW_CaO_corr"] = corr_m_wt("BaO") + corr_m_wt("SrO") + corr_m_wt("CaO")
+    df["MW_K2O_corr"] = corr_m_wt("Rb2O") + corr_m_wt("Cs2O") + corr_m_wt("K2O")
+    df["MW_Na2O_corr"] = corr_m_wt("Li2O") + corr_m_wt("Na2O")
+    df["MW_Cr2O3_corr"] = corr_m_wt("V2O3") + corr_m_wt("Cr2O3")
 
     # Corrected molecular weight of Ca, Na and Fe
-    corrected_mass["Ca"] = corrected_mass["CaO"] - pt.O.mass
-    corrected_mass["Na"] = (corrected_mass["Na2O"] - pt.O.mass) / 2
-    corrected_mass["Fe"] = corrected_mass["FeO"] - pt.O.mass
+    df["MW_Ca_corr"] = df["MW_CaO_corr"] - pt.O.mass
+    df["MW_Na_corr"] = (df["MW_Na2O_corr"] - pt.O.mass) / 2
+    df["MW_Fe_corr"] = df["MW_FeO_corr"] - pt.O.mass
 
-    # Get mineral data, update with corrected masses
+    for m in ["Q", "Z", "C", "Ru", "Hm", "Mg-Ol", "Mg-Hy"]:
+        minerals[m]["mass"] = pt.formula(minerals[m]["formulae"]).mass
 
-    minerals = {
-        k: {**v} for k, v in NORM_MINERALS.items()
-    }  # copy the dictionary rather than edit it
-
-    _update_molecular_masses(minerals, corrected_mass)
+    minerals["Fe-Hy"]["mass"] = df["MW_FeO_corr"] + pt.formula("SiO2").mass
+    minerals["Fe-Ol"]["mass"] = (2 * df["MW_FeO_corr"]) + pt.formula("SiO2").mass
+    minerals["Mt"]["mass"] = df["MW_FeO_corr"] + pt.formula("Fe2O3").mass
+    minerals["Il"]["mass"] = df["MW_FeO_corr"] + pt.formula("TiO2").mass
+    minerals["An"]["mass"] = df["MW_CaO_corr"] + pt.formula("Al2O3 (SiO2)2").mass
+    minerals["Mg-Di"]["mass"] = df["MW_CaO_corr"] + pt.formula("MgO (SiO2)2").mass
+    minerals["Wo"]["mass"] = df["MW_CaO_corr"] + pt.formula("SiO2").mass
+    minerals["Cs"]["mass"] = 2 * df["MW_CaO_corr"] + pt.formula("SiO2").mass
+    minerals["Tn"]["mass"] = df["MW_CaO_corr"] + pt.formula("TiO2 SiO2").mass
+    minerals["Pf"]["mass"] = df["MW_CaO_corr"] + pt.formula("TiO2").mass
+    minerals["CaF2-Ap"]["mass"] = (
+        3 * df["MW_CaO_corr"]
+        + (1 / 3) * df["MW_Ca_corr"]
+        + (2 / 3) * pt.F.mass
+        + pt.formula("P2O5").mass
+    )
+    minerals["Ap"]["mass"] = (10 / 3) * df["MW_CaO_corr"] + pt.formula("P2O5").mass
+    minerals["Cc"]["mass"] = df["MW_CaO_corr"] + pt.formula("CO2").mass
+    minerals["Ab"]["mass"] = df["MW_Na2O_corr"] + pt.formula("Al2O3 (SiO2)6").mass
+    minerals["Ne"]["mass"] = df["MW_Na2O_corr"] + pt.formula("Al2O3 (SiO2)2").mass
+    minerals["Th"]["mass"] = df["MW_Na2O_corr"] + pt.formula("SO3").mass
+    minerals["Nc"]["mass"] = df["MW_Na2O_corr"] + pt.formula("CO2").mass
+    minerals["Ac"]["mass"] = df["MW_Na2O_corr"] + pt.formula("Fe2O3 (SiO2)4").mass
+    minerals["Ns"]["mass"] = df["MW_Na2O_corr"] + pt.formula("SiO2").mass
+    minerals["Or"]["mass"] = df["MW_K2O_corr"] + pt.formula("Al2O3 (SiO2)6").mass
+    minerals["Lc"]["mass"] = df["MW_K2O_corr"] + pt.formula("Al2O3 (SiO2)4").mass
+    minerals["Kp"]["mass"] = df["MW_K2O_corr"] + pt.formula("Al2O3 (SiO2)2").mass
+    minerals["Ks"]["mass"] = df["MW_K2O_corr"] + pt.formula("SiO2").mass
+    minerals["Fe-Di"]["mass"] = (
+        df["MW_FeO_corr"] + df["MW_CaO_corr"] + pt.formula("(SiO2)2").mass
+    )
+    minerals["Cm"]["mass"] = df["MW_FeO_corr"] + df["MW_Cr2O3_corr"]
+    minerals["Hl"]["mass"] = df["MW_Na_corr"] + pt.formula("Cl").mass
+    minerals["Fr"]["mass"] = df["MW_Ca_corr"] + pt.formula("F2").mass
+    minerals["Pr"]["mass"] = df["MW_Fe_corr"] + pt.formula("S2").mass
 
     df["Y"] = 0
 
@@ -661,7 +835,9 @@ def CIPW_norm(df, Fe_correction=None, Fe_correction_mode=None, adjust_all_Fe=Fal
     # Normative Pyrite
     df["Pr"] = np.where(df["FeO"] >= 2 * df["S"], df["S"] / 2, df["FeO"]).T
 
-    df["FeO"] = np.where(df["FeO"] >= 2 * df["S"], df["FeO"] - df["Pr"], 0).T
+    df["FeO"] = np.where(
+        df["FeO"] >= 2 * df["S"], df["FeO"] - df["Pr"], df["FeO"] - df["Pr"] * 2
+    ).T
 
     df["FREE_S"] = np.where(df["FeO"] >= 2 * df["S"], 0, df["FeO"]).T
 
@@ -670,6 +846,7 @@ def CIPW_norm(df, Fe_correction=None, Fe_correction_mode=None, adjust_all_Fe=Fal
     df["FREEO_16"] = df["Pr"]
 
     # Normative sodium carbonate (cancrinite) or calcite
+
     df["Nc"] = np.where(df["Na2O"] >= df["CO2"], df["CO2"], df["Na2O"]).T
 
     df["Na2O"] = np.where(df["Na2O"] >= df["CO2"], df["Na2O"] - df["Nc"], df["Na2O"]).T
@@ -724,7 +901,7 @@ def CIPW_norm(df, Fe_correction=None, Fe_correction_mode=None, adjust_all_Fe=Fal
     df["Al2O3"] = df["Al2O3_"]
     df["K2O"] = df["K2O_"]
 
-    # Normative Albite (provisional)
+    # Normative Albite
     df["Ab_p"] = np.where(df["Al2O3"] >= df["Na2O"], df["Na2O"], df["Al2O3"]).T
 
     df["Al2O3_"] = np.where(df["Al2O3"] >= df["Na2O"], df["Al2O3"] - df["Ab_p"], 0).T
@@ -736,7 +913,7 @@ def CIPW_norm(df, Fe_correction=None, Fe_correction_mode=None, adjust_all_Fe=Fal
     df["Al2O3"] = df["Al2O3_"]
     df["Na2O"] = df["Na2O_"]
 
-    # Normative Acmite / sodium metasilicate - 2(NaFe3+Si2O6), Na2SiO3
+    # Normative Acmite / sodium metasilicate
     df["Ac"] = np.where(df["Na2O"] >= df["Fe2O3"], df["Fe2O3"], df["Na2O"]).T
 
     df["Na2O_"] = np.where(df["Na2O"] >= df["Fe2O3"], df["Na2O"] - df["Ac"], 0).T
@@ -786,9 +963,9 @@ def CIPW_norm(df, Fe_correction=None, Fe_correction_mode=None, adjust_all_Fe=Fal
     # Normative Magnetite / Hematite
     df["Mt"] = np.where(df["Fe2O3"] >= df["FeO"], df["FeO"], df["Fe2O3"]).T
 
-    df["Fe2O3_"] = np.where(df["Fe2O3"] >= df["FeO"], df["Fe2O3"] - df["Mt"], 0.0).T
+    df["Fe2O3_"] = np.where(df["Fe2O3"] >= df["FeO"], df["Fe2O3"] - df["Mt"], 0).T
 
-    df["FeO_"] = np.where(df["Fe2O3"] >= df["FeO"], 0.0, df["FeO"] - df["Mt"]).T
+    df["FeO_"] = np.where(df["Fe2O3"] >= df["FeO"], 0, df["FeO"] - df["Mt"]).T
 
     df["Fe2O3"] = df["Fe2O3_"]
 
@@ -803,7 +980,7 @@ def CIPW_norm(df, Fe_correction=None, Fe_correction_mode=None, adjust_all_Fe=Fal
     df["MgO_ratio"] = df["MgO"] / df["MgFe_O"]
     df["FeO_ratio"] = df["FeO"] / df["MgFe_O"]
 
-    # Provisional normative dioside, wollastonite / Hypersthene
+    # Provisional normative diopside, wollastonite / Hypersthene
     df["Di_p"] = np.where(df["CaO"] >= df["MgFe_O"], df["MgFe_O"], df["CaO"]).T
 
     df["CaO_"] = np.where(df["CaO"] >= df["MgFe_O"], df["CaO"] - df["Di_p"], 0).T
@@ -830,7 +1007,7 @@ def CIPW_norm(df, Fe_correction=None, Fe_correction_mode=None, adjust_all_Fe=Fal
 
     df["deficit"] = df["D"] > 0
 
-    # Normative Olivine / Hypersthene - Mg2SiO4, MgSiO3
+    # Normative Olivine / Hypersthene
     df["Ol_"] = np.where((df["D"] < df["Hy_p"] / 2), df["D"], df["Hy_p"] / 2).T
 
     df["Hy"] = np.where((df["D"] < df["Hy_p"] / 2), df["Hy_p"] - 2 * df["D"], 0).T
@@ -843,7 +1020,7 @@ def CIPW_norm(df, Fe_correction=None, Fe_correction_mode=None, adjust_all_Fe=Fal
 
     df["deficit"] = df["D1"] > 0
 
-    # Normative Sphene / Perovskite - CaTiSiO5 / CaTiO3
+    # Normative Sphene / Perovskite
     df["Tn"] = np.where((df["D1"] < df["Tn_p"]), df["Tn_p"] - df["D1"], 0).T
 
     df["Pf_"] = np.where((df["D1"] < df["Tn_p"]), df["D1"], df["Tn_p"]).T
@@ -855,7 +1032,7 @@ def CIPW_norm(df, Fe_correction=None, Fe_correction_mode=None, adjust_all_Fe=Fal
 
     df["deficit"] = df["D2"] > 0
 
-    # Normative Nepheline / Albite - 2(NaAlSi3O8) / 2(NaAlSiO8)
+    # Normative Nepheline / Albite
     df["Ne_"] = np.where((df["D2"] < 4 * df["Ab_p"]), df["D2"] / 4, df["Ab_p"]).T
 
     df["Ab"] = np.where((df["D2"] < 4 * df["Ab_p"]), df["Ab_p"] - df["D2"] / 4, 0).T
@@ -936,9 +1113,6 @@ def CIPW_norm(df, Fe_correction=None, Fe_correction_mode=None, adjust_all_Fe=Fal
 
     ############################################################################
     # calculate free component molecular abundances
-    #
-    # Note that this accounts for potential differnces between mass used in
-    # Verma's implementation and that of periodictable
     ############################################################################
     FREE = pd.DataFrame()
 
@@ -1013,8 +1187,8 @@ def CIPW_norm(df, Fe_correction=None, Fe_correction_mode=None, adjust_all_Fe=Fal
                 + (df["CaO-Ap"] * minerals["Ap"]["mass"]),
             )
         else:
-            mineral_proportions[mineral] = df.loc[:, mineral]
-            mineral_pct_mm[mineral] = df.loc[:, mineral] * minerals[mineral]["mass"]
+            mineral_proportions[mineral] = df[mineral]  # molar proportions
+            mineral_pct_mm[mineral] = df[mineral] * minerals[mineral]["mass"]
 
     # rename columns with proper names rather than abbreviations
     mineral_pct_mm.columns = [
