@@ -8,8 +8,10 @@ Todo
 
 from ...util.log import Handle
 from .feldspar import FeldsparTernary
+from .jensen import JensenPlot
 from .pearce import pearceThNbYb, pearceTiNbYb
 from .QAP import QAP
+from .spinel import SpinelFeBivariate, SpinelTrivalentTernary
 from .TAS import TAS
 from .USDA_soil_texture import USDASoilTexture
 
@@ -18,8 +20,11 @@ logger = Handle(__name__)
 __all__ = [
     "pearceThNbYb",
     "pearceTiNbYb",
+    "JensenPlot",
     "TAS",
     "USDASoilTexture",
     "QAP",
     "FeldsparTernary",
+    "SpinelFeBivariate",
+    "SpinelTrivalentTernary",
 ]
