@@ -17,12 +17,6 @@ from ..log import Handle
 
 logger = Handle(__name__)
 
-if platform == "darwin":
-    logger.debug("Using TkAgg renderer for Mac.")
-    import matplotlib
-
-    matplotlib.use("TkAgg")
-
 from .density import USE_PCOLOR
 from .style import DEFAULT_CONT_COLORMAP, DEFAULT_DISC_COLORMAP
 
